cd "SET WORKING DIRECTORY"

use "public_data_main.dta", clear

cd "noisy_tables"
//state indicators
tab state_id, gen(st_)


**PARTY Activity SCALE (GRM)
irt grm  octoberofnonelectionyearbearingi-octoberofe howmanypeo- v271
predict party_activity, latent

//"Typical" chairs above/below mean (discussion in text) 
sum octoberofnonelectionyearbearingi-octoberofe howmanypeo- v271 if party_activity>-1.25 & party_activity<-.75, det
sum octoberofnonelectionyearbearingi-octoberofe howmanypeo- v271 if party_activity<1.25 & party_activity>.75, det



//Alt Measure MEAN INDEX (see Table A4)
alpha octoberofnonelectionyearbearingi-octoberofe howmanypeo- v271, std gen(mean_index)

//Alt Measure: factor analysis (See Table A5)
factor octoberofnonelectionyearbearingi-octoberofe howmanypeo- v271
rotate, factors(2)
predict prof_act prof_time

//STANDARDIZE indices to have Mean = 0; SD =1 
foreach i in party_activity prof_act prof_time mean_index{
qui sum `i'
replace `i'=(`i'-r(mean))/r(sd)
}
//Label Activity Measures
label var party_activity "Local Party Activity (M=0; SD=1)"
label var prof_act "Local Party Activity (Factor 1)"
label var prof_time "Local Party Activity (Factor 2)"
label var mean_index "Local Party Activity (Mean Index; M=0, SD=1)"


***disadvantaged, competition, dominance indicators
recode own_pty_pres_12 (0/45=1) (45/55=2) (55/100=3), gen(comp_measure)
tab comp_measure, gen(comp_)
drop comp_1
label var comp_2 "Electoral Competition"
label var comp_3 "Electoral Dominance"
//rename ordered, used in interaction (##) models below to create figures 
rename comp_measure XXXX_comp_measure

//Alternate competetiveness measures (see Table A6)
recode own_pty_pres_12 (0/40=1) (40/60=2) (60/100=3), gen(alt_comp_measure)
tab alt_comp_measure, gen(alt_comp_)
drop alt_comp_1
label var alt_comp_2 "Electoral Competition"
label var alt_comp_3 "Electoral Dominance"
drop alt_comp_measure


//REPRESENTATIVENESS (TABLE A1)
sum  perc_black_hh perc_hisp_hh median_inc coll_grad ln_population obama_vote if democrat==0, sep(0)
sum  perc_black_hh perc_hisp_hh median_inc coll_grad ln_population obama_vote if democrat==1, sep(0)

*summary stats - Appendix Table A2
outsum age female r_white r_black r_hispanic r_other educ income incomemis democrat own_pty_pres_12 own_pty_pres_16 own_pty_house_16 own_pty_house_alt_16 own_pty_sen_16 democrat perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A2_sumstats", replace bracket

//TABLES 1 and A3
foreach i of varlist octoberofnonelectionyearbearingi-octoberofe howmanypeo- v271{
tab `i'
}


//COMPETETIVENESS x LPA INTERACTIONS
gen party_activityXcomp_2=party_activity*comp_2
gen party_activityXcomp_3=party_activity*comp_3
label var party_activityXcomp_2 "LPA x Electoral Competition"
label var party_activityXcomp_3 "LPA x Electoral Dominance"

gen party_activityXalt_comp_2=party_activity*alt_comp_2
gen party_activityXalt_comp_3=party_activity*alt_comp_3
label var party_activityXalt_comp_2 "LPA x Electoral Competition"
label var party_activityXalt_comp_3 "LPA x Electoral Dominance"

gen ownwinXparty_activity =own_win_12*party_activity 
label var ownwinXparty_activity "Local Party Activity x Own Party Won County (2012)"


foreach i of varlist party_activity prof_time prof_act mean_index mrp_ideology perc_black_hh perc_hisp_hh median_inc coll_grad ln_population{
gen demX`i'=democrat*`i'
local label : variable label `i'
label var demX`i' "Democrat x `label'"
}
rename demXparty_activity XdemXparty_activity
rename demXmrp XdemXmrp
rename demXprof_time XXdemXprof_time
rename demXprof_act XXdemXprof_act
rename demXmean_index XXdemXmean_index


*********PARTY ACTIVITY AND ELECTORAL PAST (Appendix Table A15)
gen sq_own_pty_pres_12=(own_pty_pres_12^2)/100
label var sq_own_pty_pres_12 "Two-Party Vote Won by Party (2012; Squared/100)"
gen cube_own_pty_pres_12=(own_pty_pres_12^3)/1000
label var cube_own_pty_pres_12 "Two-Party Vote Won by Party (2012; Cubed/1,000)"
gen q_own_pty_pres_12=own_pty_pres_12^4
label var q_own_pty_pres_12 "Two-Party Vote Won by Party (2012; ^4)"

gen own_pty_pres_12Xcomp_2=own_pty_pres_12*comp_2
gen own_pty_pres_12Xcomp_3=own_pty_pres_12*comp_3
label var own_pty_pres_12Xcomp_2 "Two-Party Pres. Vote Won by Party x Electoral Competition"
label var own_pty_pres_12Xcomp_3 "Two-Party Pres. Vote Won by Party x Electoral Dominance"

//no top-level diff between parties
reg party_activity democrat, cluster(fips)
reg party_activity own_pty_pres_12 democrat  perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
reg party_activity own_pty_pres_12 democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
outreg own_pty_pres_12 ln_population democrat perc_black_hh perc_hisp_hh median_inc coll_grad demX* using "A15_pred_LPA", se bracket tdec(3) replace label 

reg party_activity own_pty_pres_12 sq_own_pty_pres_12 democrat demX*  perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
outreg own_pty_pres_12 sq_own_pty_pres_12 ln_population democrat perc_black_hh perc_hisp_hh median_inc coll_grad demX*  using "A15_pred_LPA", se bracket tdec(3) append label 

reg party_activity own_pty_pres_12 sq_own_pty_pres_12 cube_own_pty_pres_12 democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
outreg own_pty_pres_12 sq_own_pty_pres_12 cube_own_pty_pres_12 ln_population democrat perc_black_hh perc_hisp_hh median_inc coll_grad demX*  using "A15_pred_LPA", se bracket tdec(3) append label 

reg party_activity own_pty_pres_12 comp_2 comp_3 own_pty_pres_12Xcomp_2 own_pty_pres_12Xcomp_3 democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
outreg own_pty_pres_12 comp_2 comp_3 own_pty_pres_12Xcomp_2 own_pty_pres_12Xcomp_3 ln_population democrat perc_black_hh perc_hisp_hh median_inc coll_grad demX*  using "A15_pred_LPA", se bracket tdec(3) append label 
//Magnitude/slope estimates reported in paper
lincom own_pty_pres_12+own_pty_pres_12Xcomp_2 
lincom own_pty_pres_12+own_pty_pres_12Xcomp_3

lincom (own_pty_pres_12)*34
lincom (own_pty_pres_12+own_pty_pres_12Xcomp_2)*34
lincom (own_pty_pres_12+own_pty_pres_12Xcomp_3)*34


reg party_activity democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
predict prof_resid, resid
recode own_pty_pres_12 (0/20=20) (80/100=80), gen(trun_own_pty_pres_12)
twoway (lowess prof_resid trun_own_pty_pres_12, lwidth(thick) lcolor(black)) (lowess prof_resid trun_own_pty_pres_12 if democrat==1, lwidth(medium) lcolor(black)) (lowess prof_resid trun_own_pty_pres_12 if democrat==0, lwidth(thick) lcolor(black) lpattern(dash)) (lowess party_activity trun_own_pty_pres_12, lwidth(thick) lcolor(gs10) yaxis(2)) ,  legend(region(lcolor(white))  cols(4)  order(2 "Democrats" 3 "Republicans" 1 "All" 4 "All (Raw)")) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) xtitle("Share of Presidential Vote Won by Party (2012)", size(medium)) ytitle("Local Party Activity (Residualized)", margin(0 2 0 0)) ytitle("Local Party Activity (Raw)", axis(2)) xlabel(20(5)80)
graph export "A1_perform_lowess.eps", as(eps) replace


reg party_activity  c.own_pty_pres_12##c.own_pty_pres_12##c.own_pty_pres_12 democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
margins, at(own_pty_pres_12==(20(2)80)) 
marginsplot, plotopts(lwidth(thick) lcolor(black)) ciopts(color(gs14)) recast(line) recastci(rarea) legend(off) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) xlabel(20(10)80) xtitle("Share of Presidential Vote Won by Party (2012)", size(medium)) ytitle("Local Party Activity") title("") xline(50, lwidth(vthin) lcolor(gs10) lpattern(dash)) ylab(, nogrid) xlabel(20(5)80)
graph export "A2_cube_perform_param.eps", as(eps) replace


***********OUTCOME FX MODELS (Table 2)***********
foreach i in pres house sen   {
reg own_pty_`i'_16  party_activity democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
if "`i'"=="pres"{
outreg party_activity perc_black_hh perc_hisp_hh median_inc coll_grad ln_population democrat demX* using "T2_core_analysis", se bracket tdec(3) replace label 
}
else{
outreg party_activity perc_black_hh perc_hisp_hh median_inc coll_grad ln_population democrat demX* using "T2_core_analysis", se bracket tdec(3) append label
}

reg own_pty_`i'_16  party_activity mrp_ideology XdemXmrp democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
outreg party_activity mrp_ideology XdemXmrp democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population  using "T2_core_analysis", se bracket tdec(3) append label 

reg own_pty_`i'_16  party_activity mrp_ideology XdemXmrp democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3   demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)

outreg party_activity  mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "T2_core_analysis", se bracket tdec(3) append label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 

//FOR COMPARISON OF COMPETITIVENESS THRESHOLDS (Table A6)
if "`i'"=="pres"{
outreg party_activity  mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A6_alt_comp_pooled", se bracket tdec(3) replace label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 
}
else{
outreg party_activity  mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A6_alt_comp_pooled", se bracket tdec(3) append label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 
}
reg own_pty_`i'_16  party_activity mrp_ideology XdemXmrp democrat alt_comp_2 alt_comp_3 party_activityXalt_comp_2 party_activityXalt_comp_3   demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
lincom party_activity+party_activityXalt_comp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXalt_comp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXalt_comp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXalt_comp_3)==0
local pval_3=round(r(p),.001)
outreg party_activity  mrp_ideology democrat alt_comp_2 alt_comp_3 party_activityXalt_comp_2 party_activityXalt_comp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A6_alt_comp_pooled", se bracket tdec(3) append label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 

//PLACEHOLDERS for P-VALUEs/Estimates (bottom rows of table)
local esimate_2=1000
local esimate_3=1000
local pval_2=1000
local pval_3=1000
reg own_pty_`i'_16  party_activity mrp_ideology XdemXmrp democrat own_win_12 ownwinXparty_activity demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
lincom party_activity+ownwinXparty_activity
local est=round(r(estimate),.001)
test (party_activity+ownwinXparty_activity)==0
local pval=round(r(p),.001)
outreg party_activity  mrp_ideology democrat own_win_12 ownwinXparty_activity XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A6_alt_comp_pooled", se bracket tdec(3) append label addstat("LPA if Own Party Won (2012); (b)", `est',"p-value (if Own Party Won)", `pval') 

}

foreach i in pres house sen   {
** MODELS excluding FEs (Table A12)
reg own_pty_`i'_16  party_activity mrp_ideology XdemXmrp democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3   demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population, cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)

if "`i'"=="pres"{
outreg party_activity  mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A12_no_state_fes", se bracket tdec(3) replace label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 
}
else{
outreg party_activity  mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A12_no_state_fes", se bracket tdec(3) append label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 
}

}

//GRAPH INTERACTIONS (Figure 1)
preserve
drop party_activityXcomp_2 party_activityXcomp_3
foreach i in pres house    {
if "`i'"=="pres"{
local elec="Panel A: Presidential" 
}
if "`i'"=="house"{
local elec="Panel B: House"
}
reg own_pty_`i'_16  c.party_activity##i.XXXX_comp_measure mrp_ideology XdemXmrp democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
qui margins XXXX_comp_measure, atmeans at(party_activity=(-3(.1)3))
marginsplot, xlabel(-3(1)3) recast(line) recastci(rline) plot1opts(lcolor(black) lpattern(solid) lwidth(thick)) ci1opts(lcolor(gs8) lwidth(thin)) plot2opts(lcolor(black) lpattern(shortdash) lwidth(thick)) ci2opts(lcolor(gs8) lwidth(thin)) plot3opts(lcolor(black) lpattern(longdash) lwidth(thick)) ci3opts(lcolor(gs8) lwidth(thin))  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) xtitle("Local Party Activity (M=0; SD=1)", size(large)) ytitle("Predicted Share of Two-Party Vote", size(large)) title("") ylab(, nogrid) title("`elec'", size(vlarge)) legend(region(lcolor(white))  cols(3)  order(4 "Electoral" "Disadvantage" 5 "Electoral" "Competition" 6 "Electoral" "Advantage")) 
graph save Graph "interact_`i'.gph", replace
}
grc1leg interact_pres.gph interact_house.gph, col(2) ycommon  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) 
graph export "F1_interactions.eps", as(eps) replace

restore


** BY BATTLEGROUND STATUS (Table A10)
foreach i in pres {
forvalues b=0/1{
reg own_pty_`i'_16  party_activity mrp_ideology XdemXmrp democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3   demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population if battleground==`b', cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)

if "`i'"=="pres" & `b'==0{
outreg party_activity  mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A10_battlegrounds", se bracket tdec(3) replace label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 
}
else{
outreg party_activity  mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A10_battlegrounds", se bracket tdec(3) append label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 
}
}
}


** BY COUNTY POPULATION (Table A11)
xtile q_pop=ln_population, nq(3)
label var q_pop "County Population Tercile"
foreach i in pres house sen   {
forvalues p=1/3{
reg own_pty_`i'_16  party_activity mrp_ideology XdemXmrp democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3   demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population if q_pop==`p', cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)

if "`i'"=="pres" & `p'==1{
outreg party_activity  mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A11_by_population", se bracket tdec(3) replace label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 
}
else{
outreg party_activity  mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A11_by_population", se bracket tdec(3) append label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 
}
}
}

**Share of VAP, rather than share of 2-party vote (Table A9)***********
foreach i in pres house sen   {
reg vap_own_pty_`i' party_activity mrp_ideology XdemXmrp democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)

if "`i'"=="pres"{
outreg party_activity mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3 XdemXmrp demX*  perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A8_vap_analysis", se bracket tdec(3) replace label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 
}
else{
outreg party_activity mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A8_vap_analysis", se bracket tdec(3) append label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 
}
}

**DV = Turnout (Table A14)***********
reg turnout party_activity mrp_ideology XdemXmrp democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)

outreg party_activity mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3 XdemXmrp demX*  perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A14_turnout", se bracket tdec(3) replace label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 

*** HOUSE: CONTESTED ONLY (Table A7)

reg own_pty_house_alt_16  party_activity democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
outreg party_activity perc_black_hh perc_hisp_hh median_inc coll_grad ln_population democrat demX* using "A7_contested_house", se bracket tdec(3) replace label 

reg own_pty_house_alt_16  party_activity mrp_ideology XdemXmrp democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
outreg party_activity mrp_ideology XdemXmrp democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population  using "A7_contested_house", se bracket tdec(3) append label 

reg own_pty_house_alt_16  party_activity mrp_ideology XdemXmrp democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)
outreg party_activity mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A7_contested_house", se bracket tdec(3) append label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 



***BY PARTY (Table A9)
foreach i in pres house sen  {
reg own_pty_`i'_16  party_activity mrp_ideology comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_* if democrat==0, cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)

if "`i'"=="pres"{
outreg party_activity mrp_ideology comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3 perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A9_by_party", se bracket tdec(3) replace label  addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 
}
else{
outreg party_activity mrp_ideology comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A9_by_party", se bracket tdec(3) append label  addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 
}

reg own_pty_`i'_16  party_activity mrp_ideology comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3 perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_* if democrat==1, cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)

outreg party_activity mrp_ideology comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A9_by_party", se bracket tdec(3) append label  addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 
}


**THREE WAY Party INTERACTIONS (Not significant)
foreach i in pres house sen   {
qui reg own_pty_`i'_16 c.party_activity##comp_2##democrat c.party_activity##comp_3##democrat  democrat##(c.mrp_ideology c.perc_black_hh c.perc_hisp_hh c.median_inc c.coll_grad c.ln_population) st_*, cluster(fips)
testparm comp_2#democrat#c.party_activity
testparm comp_3#democrat#c.party_activity
}


***ALTERNATE ACTIVITY MEASURES (A4 and A5)
********FACTOR ANALYSIS MEASURES
rename party_activityXcomp_2 Xparty_activityXcomp_2 
rename party_activityXcomp_3 Xparty_activityXcomp_3 
foreach i in prof_act prof_time {
local label : variable label `i'
gen `i'Xcomp_2 =`i'*comp_2
gen `i'Xcomp_3 =`i'*comp_3
label var `i'Xcomp_2 "`label' x Electoral Competition"
label var `i'Xcomp_3 "`label' x Electoral Dominance"
}
foreach i in pres house sen   {
reg own_pty_`i'_16  prof_act prof_time democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
if "`i'"=="pres"{
outreg prof_act prof_time perc_black_hh perc_hisp_hh median_inc coll_grad ln_population democrat demX* using "A5_factor_measures", se bracket tdec(3) replace label 
}
else{
outreg prof_act prof_time  perc_black_hh perc_hisp_hh median_inc coll_grad ln_population democrat demX* using "A5_factor_measures", se bracket tdec(3) append label
}

reg own_pty_`i'_16  prof_act prof_time  mrp_ideology XdemXmrp democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
outreg prof_act prof_time  mrp_ideology XdemXmrp democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population  using "A5_factor_measures", se bracket tdec(3) append label 

reg own_pty_`i'_16  prof_act prof_time prof_actXcomp_2 prof_actXcomp_3 prof_timeXcomp_2 prof_timeXcomp_3 mrp_ideology XdemXmrp democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
outreg prof_act prof_time prof_actXcomp_2 prof_actXcomp_3 prof_timeXcomp_2 prof_timeXcomp_3 mrp_ideology XdemXmrp democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A5_factor_measures", se bracket tdec(3) append label 
}

********Mean Index
//drop factor analysis variables
drop prof_act* prof_time*
foreach i in mean_index{
local label : variable label `i'
gen `i'Xcomp_2 =`i'*comp_2
gen `i'Xcomp_3 =`i'*comp_3
label var `i'Xcomp_2 "`label' x Electoral Competition"
label var `i'Xcomp_3 "`label' x Electoral Dominance"
}
foreach i in pres house sen   {
reg own_pty_`i'_16  mean_index democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
if "`i'"=="pres"{
outreg mean_index perc_black_hh perc_hisp_hh median_inc coll_grad ln_population democrat demX* using "A4_mean_index", se bracket tdec(3) replace label 
}
else{
outreg mean_index perc_black_hh perc_hisp_hh median_inc coll_grad ln_population democrat demX* using "A4_mean_index", se bracket tdec(3) append label
}

reg own_pty_`i'_16  mean_index mrp_ideology XdemXmrp democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
outreg mean_index mrp_ideology XdemXmrp democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population  using "A4_mean_index", se bracket tdec(3) append label 

reg own_pty_`i'_16  mean_index mrp_ideology XdemXmrp democrat comp_2 comp_3 mean_indexXcomp_2 mean_indexXcomp_3 demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_*, cluster(fips)
lincom mean_index+mean_indexXcomp_2 
local est_2=round(r(estimate),.001)
test (mean_index+mean_indexXcomp_2)==0
local pval_2=round(r(p),.001)

lincom mean_index+mean_indexXcomp_3
local est_3=round(r(estimate),.001)
test (mean_index+mean_indexXcomp_3)==0
local pval_3=round(r(p),.001)

outreg mean_index  mrp_ideology democrat comp_2 comp_3 mean_indexXcomp_2 mean_indexXcomp_3 XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A4_mean_index", se bracket tdec(3) append label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 
}


***********************************
** COUNTIES W/MULTIPLE HOUSE DISTRICTS (Table A13)
** SEPARATE DATA FILE USED DUE TO NEED TO MATCH PRIVATE (FIPS) VARIABLE TO HOUSE/COUNTY MATCH FILE

use "../public_data_A13.dta", clear
** HAVE TO REBUILD SOME VARIABLES THAT WERE BUILT ABOVE USING THE OTHER DATASET FIRST 
//state indicators
tab state_id, gen(st_)

**INTERACTIONS
foreach i of varlist party_activity mrp_ideology perc_black_hh perc_hisp_hh median_inc coll_grad ln_population{
gen demX`i'=democrat*`i'
local label : variable label `i'
label var demX`i' "Democrat x `label'"
}
rename demXparty_activity XdemXparty_activity
rename demXmrp XdemXmrp

***disadvantaged, competition, dominance indicators
recode own_pty_pres_12 (0/45=1) (45/55=2) (55/100=3), gen(comp_measure)
tab comp_measure, gen(comp_)
drop comp_1
label var comp_2 "Electoral Competition"
label var comp_3 "Electoral Dominance"

//COMPETETIVENESS x LPA INTERACTIONS
gen party_activityXcomp_2=party_activity*comp_2
gen party_activityXcomp_3=party_activity*comp_3
label var party_activityXcomp_2 "LPA x Electoral Competition"
label var party_activityXcomp_3 "LPA x Electoral Dominance"

reg own_pty_house_16  party_activity mrp_ideology XdemXmrp democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3   demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_* if multiple_counties==1, cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)
outreg party_activity  mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A13_district_overlaps", se bracket tdec(3) replace label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 

reg own_pty_house_16  party_activity mrp_ideology XdemXmrp democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3   demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population if multiple_counties==1, cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)
outreg party_activity  mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A13_district_overlaps", se bracket tdec(3) append ctitle("No FEs") label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 

///COUNTIES W/MULTIPLE HOUSE DISTRICTS
reg own_pty_house_16  party_activity comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3 mrp_ideology XdemXmrp democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population st_* if multiple_dist==1, cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)
outreg party_activity  mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A13_district_overlaps", se bracket tdec(3) append label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 

reg own_pty_house_16  party_activity comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3 mrp_ideology XdemXmrp democrat demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population if multiple_dist==1, cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)
outreg party_activity  mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp demX* perc_black_hh perc_hisp_hh median_inc coll_grad ln_population using "A13_district_overlaps", se bracket tdec(3) append ctitle("No FEs") label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 

reg own_pty_house_16  party_activity comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3 mrp_ideology XdemXmrp democrat st_* if multiple_dist==1, cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)
outreg party_activity  mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp using "A13_district_overlaps", se bracket tdec(3) append label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 

reg own_pty_house_16  party_activity comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3 mrp_ideology XdemXmrp democrat if multiple_dist==1, cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)
outreg party_activity  mrp_ideology democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  XdemXmrp using "A13_district_overlaps", se bracket tdec(3) append ctitle("No FEs") label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 

reg own_pty_house_16  party_activity comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3 democrat st_* if multiple_dist==1, cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)
outreg party_activity   democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  using "A13_district_overlaps", se bracket tdec(3) append label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 

reg own_pty_house_16  party_activity comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3 democrat if multiple_dist==1, cluster(fips)
lincom party_activity+party_activityXcomp_2
local est_2=round(r(estimate),.001)
test (party_activity+party_activityXcomp_2)==0
local pval_2=round(r(p),.001)

lincom party_activity+party_activityXcomp_3
local est_3=round(r(estimate),.001)
test (party_activity+party_activityXcomp_3)==0
local pval_3=round(r(p),.001)
outreg party_activity democrat comp_2 comp_3 party_activityXcomp_2 party_activityXcomp_3  using "A13_district_overlaps", se bracket tdec(3) append ctitle("No FEs") label addstat("LPA if Competitive County; (b)", `est_2',"p-value (if Competitive County)", `pval_2',"LPA if Party Dominant; (b)", `est_3',"p-value (if Party Dominant)", `pval_3') 

